##

##

    	possibly

    		a (DAG) database of that which is usually considered
    		food or supplements.

    			# foundational foods

    			essentials:
    				calories

    				protein

    				fat

    				sodium

    				potassium

    			ingredients:
    				bread

    				salt

    				soy bean

    				pinto bean

    				lentil

    		questions
    			cautionary ingredients?
    			poisons?
    			soaps?
    			inert objects?